@@ -3,11 +3,12 @@ var ping__channel_8h =
     [ "isc::ping_check::PingChannel", "d7/d04/classisc_1_1ping__check_1_1PingChannel.html", "d7/d04/classisc_1_1ping__check_1_1PingChannel" ],
     [ "isc::ping_check::SocketCallback", "dd/dbb/classisc_1_1ping__check_1_1SocketCallback.html", "dd/dbb/classisc_1_1ping__check_1_1SocketCallback" ],
     [ "isc::ping_check::EchoSentCallback", "d1/d21/namespaceisc_1_1ping__check.html#a6438dec74ed162e23797e56a261926c8", null ],
-    [ "isc::ping_check::NextToSendCallback", "d1/d21/namespaceisc_1_1ping__check.html#a72825bd012a29bbf462d32b9052177ae", null ],
+    [ "isc::ping_check::NextToSendCallback", "d1/d21/namespaceisc_1_1ping__check.html#aae76ee8beb9c41cc941912620fe8f950", null ],
     [ "isc::ping_check::PingChannelPtr", "d1/d21/namespaceisc_1_1ping__check.html#a97d9be46cda08ed65fb643195049a9f5", null ],
     [ "isc::ping_check::PingSocket", "d1/d21/namespaceisc_1_1ping__check.html#afd79d2203170b296c135e6558e1d814a", null ],
     [ "isc::ping_check::PingSocketPtr", "d1/d21/namespaceisc_1_1ping__check.html#ae3c48272953dd8286db741af3bdd903c", null ],
     [ "isc::ping_check::ReplyReceivedCallback", "d1/d21/namespaceisc_1_1ping__check.html#a51c68fd619ae56e6b4f5907a1b59815f", null ],
     [ "isc::ping_check::ShutdownCallback", "d1/d21/namespaceisc_1_1ping__check.html#a3e18b09e6f4bbc2bda361b82368b1299", null ],
-    [ "isc::ping_check::SocketCallbackFunction", "d1/d21/namespaceisc_1_1ping__check.html#ad9ccf3d8befeb15a9eb4aa45b736f572", null ]
+    [ "isc::ping_check::SocketCallbackFunction", "d1/d21/namespaceisc_1_1ping__check.html#ad9ccf3d8befeb15a9eb4aa45b736f572", null ],
+    [ "isc::ping_check::UpdateToSendCallback", "d1/d21/namespaceisc_1_1ping__check.html#a7ea7ca8ffe71a0a4328ba49d4be32af5", null ]
 ];
\ No newline at end of file
