@@ -2,7 +2,7 @@ var common__tls_8h =
 [
     [ "isc::asiolink::StreamService", "d8/dae/classisc_1_1asiolink_1_1StreamService.html", "d8/dae/classisc_1_1asiolink_1_1StreamService" ],
     [ "isc::asiolink::TlsContextBase", "d0/d7c/classisc_1_1asiolink_1_1TlsContextBase.html", "d0/d7c/classisc_1_1asiolink_1_1TlsContextBase" ],
-    [ "isc::asiolink::TlsStreamBase< Callback, TlsStreamImpl >", "d4/dcf/classisc_1_1asiolink_1_1TlsStreamBase.html", "d4/dcf/classisc_1_1asiolink_1_1TlsStreamBase" ],
+    [ "isc::asiolink::TlsStreamBase&lt; Callback, TlsStreamImpl &gt;", "d4/dcf/classisc_1_1asiolink_1_1TlsStreamBase.html", "d4/dcf/classisc_1_1asiolink_1_1TlsStreamBase" ],
     [ "isc::asiolink::TlsContextPtr", "db/db2/namespaceisc_1_1asiolink.html#a5a6c2b98f00641f6be259d5e5763fafe", null ],
     [ "isc::asiolink::TlsRole", "db/db2/namespaceisc_1_1asiolink.html#adb101b3b8f38fa0a4e24b9db7d6afafc", [
       [ "isc::asiolink::CLIENT", "db/db2/namespaceisc_1_1asiolink.html#adb101b3b8f38fa0a4e24b9db7d6afafca92c73c4c7aaadbc984bb0f5553bdc7ad", null ],
