@@ -1,8 +1,8 @@
 var master__loader_8cc =
 [
     [ "isc::dns::MasterLoader::MasterLoaderImpl", "d4/d3b/classisc_1_1dns_1_1MasterLoader_1_1MasterLoaderImpl.html", "d4/d3b/classisc_1_1dns_1_1MasterLoader_1_1MasterLoaderImpl" ],
-    [ "pair< T1, T2 >", "d2/d11/classpair.html", "d2/d11/classpair" ],
+    [ "pair&lt; T1, T2 &gt;", "d2/d11/classpair.html", "d2/d11/classpair" ],
     [ "string", "d5/d92/classstring.html", "d5/d92/classstring" ],
-    [ "unique_ptr< T >", "dd/d67/classunique__ptr.html", "dd/d67/classunique__ptr" ],
-    [ "vector< T >", "d7/dfc/classvector.html", "d7/dfc/classvector" ]
+    [ "unique_ptr&lt; T &gt;", "dd/d67/classunique__ptr.html", "dd/d67/classunique__ptr" ],
+    [ "vector&lt; T &gt;", "d7/dfc/classvector.html", "d7/dfc/classvector" ]
 ];
\ No newline at end of file
